read_zip: Read downloaded data from a zip file

View source: R/read_zip.R

read_zipR Documentation

Read downloaded data from a zip file

Description

Living atlases supply data downloads as zip files. This function reads these data efficiently, i.e. without unzipping them first, using the readr package. Although this function is mostly called internally, it is exported to allow easy re-importing of downloaded files, without the need to re-run a query.

Usage

read_zip(file)

Arguments

file

(character) A file name. Must be a length-1 character ending in .zip.

Examples

## Not run: 
# set a working directory
galah_config(directory = "data-raw",
             email = "an-email-address@email.com")

# download some data
galah_call() |>
  identify("Heleioporus") |>
  filter(year == 2022) |>
  collect(file = "burrowing_frog_data.zip")
  
# load data from file
x <- read_zip("./data-raw/burrowing_frog_data.zip")

## End(Not run)

galah documentation built on Sept. 18, 2026, 9:08 a.m.