describe: Describe what fields are available

View source: R/describe.R

describeR Documentation

Describe what fields are available

Description

Unlike a local tibble, where printing to the console shows what fields are available, when working remotely there is no way to know what fields are present that can be queried. This function name is borrowed from SQL, where it is used to give a read-out of fields that are in the source database. [Experimental]

Usage

describe(x, ...)

## S3 method for class 'data_request'
describe(x, ...)

Arguments

x

An object of class data_request

...

Other arguments, currently ignored

Value

A tibble showing the id, description and data_type for all fields, or if select() is called, then those fields requested by the user. See select() for other examples of valid group values.

See Also

glimpse() for a different way to view results of a query; show_all_fields() for full metadata on available fields; distinct() for showing the values within a given field.

Examples

## Not run: 
# By default, this shows all fields in the source system
galah_call() |>
  describe() |>
  collect()

# If `select()` is called, only requested fields are shown
galah_call() |>
  select(group = "basic") |>
  describe() |>
  collect()

## End(Not run)

galah documentation built on Sept. 18, 2026, 9:08 a.m.