atlas string: Living Atlas to point to, Australia by default. Can be
an organisation name, acronym, or region (see show_all_atlases() for
admissible values)
authenticate logical: Should galah use authenticate your queries using
JWT tokens? Defaults to FALSE. If TRUE, user credentials are
verified prior to sending a query. This can allow users with special
access to download additional information in galah.
caching logical: should metadata query results be cached in options()?
Defaults to TRUE for improved stability and speed.
directory string: The directory to use for the disk cache.
By default this is a temporary directory, which means that results will
only be cached within an R session and cleared automatically when the user
exits R. The user may wish to set this to a non-temporary directory for
caching across sessions. The directory must exist on the file system.
download_reason_id numeric or string: the "download reason" required.
by some ALA services, either as a numeric ID (currently 0--13)
or a string (see show_all(reasons) for a list of valid ID codes and
names). By default this is NA. Some ALA services require a valid
download_reason_id code, either specified here or directly to the
associated R function.
email string: An email address that has been registered with the chosen
atlas. For the ALA, you can register at
this address.
password string: A registered password (GBIF only)
run_checks logical: should galah run checks for filters
and columns. If making lots of requests sequentially, checks can slow down
the process and lead to HTTP 500 errors, so should be turned off. Defaults
to TRUE.
send_email logical: should you receive an email for each query to
atlas_occurrences()? Defaults to FALSE; but can be
useful in some instances, for example for tracking DOIs assigned to
specific downloads for later citation.
username string: A registered username (GBIF only)
verbose logical: should galah give verbose such as progress bars?
Defaults to FALSE.