| read_zip | R Documentation |
Living atlases supply data downloads as zip files. This function reads these
data efficiently, i.e. without unzipping them first, using the readr
package. Although this function is mostly called internally, it is exported
to allow easy re-importing of downloaded files, without the need to re-run
a query.
read_zip(file)
file |
(character) A file name. Must be a length-1 character ending in
|
## Not run:
# set a working directory
galah_config(directory = "data-raw",
email = "an-email-address@email.com")
# download some data
galah_call() |>
identify("Heleioporus") |>
filter(year == 2022) |>
collect(file = "burrowing_frog_data.zip")
# load data from file
x <- read_zip("./data-raw/burrowing_frog_data.zip")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.