if (FALSE) {
# Show values in field 'cl22'
search_fields("cl22") |>
show_values()
# This is synonymous with `request_metadata() |> unnest()`.
# For example, the previous example can be run using:
request_metadata() |>
filter(field == "cl22") |>
unnest() |>
collect()
# Search for any values in field 'cl22' that match 'tas'
search_fields("cl22") |>
search_values("tas")
# See items within species list "dr19257"
search_lists("dr19257") |>
show_values()
# Refine which columns are returned with `request_metadata()` and `select()`.
# This example is synonymous to the previous example, but with `select()`:
request_metadata() |>
filter(list == "dr19257") |>
unnest() |>
select(taxon_concept_id, supplied_name, scientific_name) |>
collect()
}
Run the code above in your browser using DataLab