| galah_apply_profile | R Documentation |
These functions are still valid, but have been superseded by more recent versions. They were designed to be used to supply arguments within functions from the atlas_ family. Instead you should use piped functions for this same functionality.
galah_apply_profile(...)
galah_filter(...)
galah_geolocate(..., type = c("polygon", "bbox", "radius"))
galah_polygon(...)
galah_bbox(...)
galah_radius(...)
galah_group_by(...)
galah_identify(...)
galah_select(..., group = NULL)
... |
Arguments passed to the function in question, usually (but not always) using non-standard evaluation. |
type |
|
group |
|
Replacements are as follows:
apply_profile() instead of galah_apply_profile()
filter() instead of galah_filter()
geolocate() instead of galah_geolocate()
geolocate_polygon() instead of galah_polygon()
geolocate_bbox() instead of galah_bbox()
geolocate_radius() instead of galah_radius()
group_by() instead of galah_group_by()
identify() instead of galah_identify()
select() instead of galah_select()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.